# Singleton

A metaclass to ensure we don't instantiate this class twice. One object will be created at the start of our application. After this, it will always use this specific instance.

::: mac_notifications.singleton.Singleton
